from enum import StrEnum


class MinecraftItemTypes(StrEnum):
    AcaciaBoat = "minecraft:acacia_boat"
    AcaciaButton = "minecraft:acacia_button"
    AcaciaChestBoat = "minecraft:acacia_chest_boat"
    AcaciaDoor = "minecraft:acacia_door"
    AcaciaFence = "minecraft:acacia_fence"
    AcaciaFenceGate = "minecraft:acacia_fence_gate"
    AcaciaHangingSign = "minecraft:acacia_hanging_sign"
    AcaciaLeaves = "minecraft:acacia_leaves"
    AcaciaLog = "minecraft:acacia_log"
    AcaciaPlanks = "minecraft:acacia_planks"
    AcaciaPressurePlate = "minecraft:acacia_pressure_plate"
    AcaciaSapling = "minecraft:acacia_sapling"
    AcaciaSign = "minecraft:acacia_sign"
    AcaciaSlab = "minecraft:acacia_slab"
    AcaciaStairs = "minecraft:acacia_stairs"
    AcaciaTrapdoor = "minecraft:acacia_trapdoor"
    AcaciaWood = "minecraft:acacia_wood"
    ActivatorRail = "minecraft:activator_rail"
    AllaySpawnEgg = "minecraft:allay_spawn_egg"
    Allium = "minecraft:allium"
    Allow = "minecraft:allow"
    AmethystBlock = "minecraft:amethyst_block"
    AmethystCluster = "minecraft:amethyst_cluster"
    AmethystShard = "minecraft:amethyst_shard"
    AncientDebris = "minecraft:ancient_debris"
    Andesite = "minecraft:andesite"
    AndesiteSlab = "minecraft:andesite_slab"
    AndesiteStairs = "minecraft:andesite_stairs"
    AndesiteWall = "minecraft:andesite_wall"
    AnglerPotterySherd = "minecraft:angler_pottery_sherd"
    Anvil = "minecraft:anvil"
    Apple = "minecraft:apple"
    ArcherPotterySherd = "minecraft:archer_pottery_sherd"
    ArmadilloScute = "minecraft:armadillo_scute"
    ArmadilloSpawnEgg = "minecraft:armadillo_spawn_egg"
    ArmorStand = "minecraft:armor_stand"
    ArmsUpPotterySherd = "minecraft:arms_up_pottery_sherd"
    Arrow = "minecraft:arrow"
    AxolotlBucket = "minecraft:axolotl_bucket"
    AxolotlSpawnEgg = "minecraft:axolotl_spawn_egg"
    Azalea = "minecraft:azalea"
    AzaleaLeaves = "minecraft:azalea_leaves"
    AzaleaLeavesFlowered = "minecraft:azalea_leaves_flowered"
    AzureBluet = "minecraft:azure_bluet"
    BakedPotato = "minecraft:baked_potato"
    Bamboo = "minecraft:bamboo"
    BambooBlock = "minecraft:bamboo_block"
    BambooButton = "minecraft:bamboo_button"
    BambooChestRaft = "minecraft:bamboo_chest_raft"
    BambooDoor = "minecraft:bamboo_door"
    BambooFence = "minecraft:bamboo_fence"
    BambooFenceGate = "minecraft:bamboo_fence_gate"
    BambooHangingSign = "minecraft:bamboo_hanging_sign"
    BambooMosaic = "minecraft:bamboo_mosaic"
    BambooMosaicSlab = "minecraft:bamboo_mosaic_slab"
    BambooMosaicStairs = "minecraft:bamboo_mosaic_stairs"
    BambooPlanks = "minecraft:bamboo_planks"
    BambooPressurePlate = "minecraft:bamboo_pressure_plate"
    BambooRaft = "minecraft:bamboo_raft"
    BambooSign = "minecraft:bamboo_sign"
    BambooSlab = "minecraft:bamboo_slab"
    BambooStairs = "minecraft:bamboo_stairs"
    BambooTrapdoor = "minecraft:bamboo_trapdoor"
    Banner = "minecraft:banner"
    Barrel = "minecraft:barrel"
    Barrier = "minecraft:barrier"
    Basalt = "minecraft:basalt"
    BatSpawnEgg = "minecraft:bat_spawn_egg"
    Beacon = "minecraft:beacon"
    Bed = "minecraft:bed"
    Bedrock = "minecraft:bedrock"
    BeeNest = "minecraft:bee_nest"
    BeeSpawnEgg = "minecraft:bee_spawn_egg"
    Beef = "minecraft:beef"
    Beehive = "minecraft:beehive"
    Beetroot = "minecraft:beetroot"
    BeetrootSeeds = "minecraft:beetroot_seeds"
    BeetrootSoup = "minecraft:beetroot_soup"
    Bell = "minecraft:bell"
    BigDripleaf = "minecraft:big_dripleaf"
    BirchBoat = "minecraft:birch_boat"
    BirchButton = "minecraft:birch_button"
    BirchChestBoat = "minecraft:birch_chest_boat"
    BirchDoor = "minecraft:birch_door"
    BirchFence = "minecraft:birch_fence"
    BirchFenceGate = "minecraft:birch_fence_gate"
    BirchHangingSign = "minecraft:birch_hanging_sign"
    BirchLeaves = "minecraft:birch_leaves"
    BirchLog = "minecraft:birch_log"
    BirchPlanks = "minecraft:birch_planks"
    BirchPressurePlate = "minecraft:birch_pressure_plate"
    BirchSapling = "minecraft:birch_sapling"
    BirchSign = "minecraft:birch_sign"
    BirchSlab = "minecraft:birch_slab"
    BirchStairs = "minecraft:birch_stairs"
    BirchTrapdoor = "minecraft:birch_trapdoor"
    BirchWood = "minecraft:birch_wood"
    BlackBundle = "minecraft:black_bundle"
    BlackCandle = "minecraft:black_candle"
    BlackCarpet = "minecraft:black_carpet"
    BlackConcrete = "minecraft:black_concrete"
    BlackConcretePowder = "minecraft:black_concrete_powder"
    BlackDye = "minecraft:black_dye"
    BlackGlazedTerracotta = "minecraft:black_glazed_terracotta"
    BlackHarness = "minecraft:black_harness"
    BlackShulkerBox = "minecraft:black_shulker_box"
    BlackStainedGlass = "minecraft:black_stained_glass"
    BlackStainedGlassPane = "minecraft:black_stained_glass_pane"
    BlackTerracotta = "minecraft:black_terracotta"
    BlackWool = "minecraft:black_wool"
    Blackstone = "minecraft:blackstone"
    BlackstoneSlab = "minecraft:blackstone_slab"
    BlackstoneStairs = "minecraft:blackstone_stairs"
    BlackstoneWall = "minecraft:blackstone_wall"
    BladePotterySherd = "minecraft:blade_pottery_sherd"
    BlastFurnace = "minecraft:blast_furnace"
    BlazePowder = "minecraft:blaze_powder"
    BlazeRod = "minecraft:blaze_rod"
    BlazeSpawnEgg = "minecraft:blaze_spawn_egg"
    BlueBundle = "minecraft:blue_bundle"
    BlueCandle = "minecraft:blue_candle"
    BlueCarpet = "minecraft:blue_carpet"
    BlueConcrete = "minecraft:blue_concrete"
    BlueConcretePowder = "minecraft:blue_concrete_powder"
    BlueDye = "minecraft:blue_dye"
    BlueEgg = "minecraft:blue_egg"
    BlueGlazedTerracotta = "minecraft:blue_glazed_terracotta"
    BlueHarness = "minecraft:blue_harness"
    BlueIce = "minecraft:blue_ice"
    BlueOrchid = "minecraft:blue_orchid"
    BlueShulkerBox = "minecraft:blue_shulker_box"
    BlueStainedGlass = "minecraft:blue_stained_glass"
    BlueStainedGlassPane = "minecraft:blue_stained_glass_pane"
    BlueTerracotta = "minecraft:blue_terracotta"
    BlueWool = "minecraft:blue_wool"
    BoggedSpawnEgg = "minecraft:bogged_spawn_egg"
    BoltArmorTrimSmithingTemplate = "minecraft:bolt_armor_trim_smithing_template"
    Bone = "minecraft:bone"
    BoneBlock = "minecraft:bone_block"
    BoneMeal = "minecraft:bone_meal"
    Book = "minecraft:book"
    Bookshelf = "minecraft:bookshelf"
    BorderBlock = "minecraft:border_block"
    BordureIndentedBannerPattern = "minecraft:bordure_indented_banner_pattern"
    Bow = "minecraft:bow"
    Bowl = "minecraft:bowl"
    BrainCoral = "minecraft:brain_coral"
    BrainCoralBlock = "minecraft:brain_coral_block"
    BrainCoralFan = "minecraft:brain_coral_fan"
    Bread = "minecraft:bread"
    BreezeRod = "minecraft:breeze_rod"
    BreezeSpawnEgg = "minecraft:breeze_spawn_egg"
    BrewerPotterySherd = "minecraft:brewer_pottery_sherd"
    BrewingStand = "minecraft:brewing_stand"
    Brick = "minecraft:brick"
    BrickBlock = "minecraft:brick_block"
    BrickSlab = "minecraft:brick_slab"
    BrickStairs = "minecraft:brick_stairs"
    BrickWall = "minecraft:brick_wall"
    BrownBundle = "minecraft:brown_bundle"
    BrownCandle = "minecraft:brown_candle"
    BrownCarpet = "minecraft:brown_carpet"
    BrownConcrete = "minecraft:brown_concrete"
    BrownConcretePowder = "minecraft:brown_concrete_powder"
    BrownDye = "minecraft:brown_dye"
    BrownEgg = "minecraft:brown_egg"
    BrownGlazedTerracotta = "minecraft:brown_glazed_terracotta"
    BrownHarness = "minecraft:brown_harness"
    BrownMushroom = "minecraft:brown_mushroom"
    BrownMushroomBlock = "minecraft:brown_mushroom_block"
    BrownShulkerBox = "minecraft:brown_shulker_box"
    BrownStainedGlass = "minecraft:brown_stained_glass"
    BrownStainedGlassPane = "minecraft:brown_stained_glass_pane"
    BrownTerracotta = "minecraft:brown_terracotta"
    BrownWool = "minecraft:brown_wool"
    Brush = "minecraft:brush"
    BubbleCoral = "minecraft:bubble_coral"
    BubbleCoralBlock = "minecraft:bubble_coral_block"
    BubbleCoralFan = "minecraft:bubble_coral_fan"
    Bucket = "minecraft:bucket"
    BuddingAmethyst = "minecraft:budding_amethyst"
    Bundle = "minecraft:bundle"
    BurnPotterySherd = "minecraft:burn_pottery_sherd"
    Bush = "minecraft:bush"
    Cactus = "minecraft:cactus"
    CactusFlower = "minecraft:cactus_flower"
    Cake = "minecraft:cake"
    Calcite = "minecraft:calcite"
    CalibratedSculkSensor = "minecraft:calibrated_sculk_sensor"
    CamelSpawnEgg = "minecraft:camel_spawn_egg"
    Campfire = "minecraft:campfire"
    Candle = "minecraft:candle"
    Carrot = "minecraft:carrot"
    CarrotOnAStick = "minecraft:carrot_on_a_stick"
    CartographyTable = "minecraft:cartography_table"
    CarvedPumpkin = "minecraft:carved_pumpkin"
    CatSpawnEgg = "minecraft:cat_spawn_egg"
    Cauldron = "minecraft:cauldron"
    CaveSpiderSpawnEgg = "minecraft:cave_spider_spawn_egg"
    Chain = "minecraft:chain"
    ChainCommandBlock = "minecraft:chain_command_block"
    ChainmailBoots = "minecraft:chainmail_boots"
    ChainmailChestplate = "minecraft:chainmail_chestplate"
    ChainmailHelmet = "minecraft:chainmail_helmet"
    ChainmailLeggings = "minecraft:chainmail_leggings"
    Charcoal = "minecraft:charcoal"
    CherryBoat = "minecraft:cherry_boat"
    CherryButton = "minecraft:cherry_button"
    CherryChestBoat = "minecraft:cherry_chest_boat"
    CherryDoor = "minecraft:cherry_door"
    CherryFence = "minecraft:cherry_fence"
    CherryFenceGate = "minecraft:cherry_fence_gate"
    CherryHangingSign = "minecraft:cherry_hanging_sign"
    CherryLeaves = "minecraft:cherry_leaves"
    CherryLog = "minecraft:cherry_log"
    CherryPlanks = "minecraft:cherry_planks"
    CherryPressurePlate = "minecraft:cherry_pressure_plate"
    CherrySapling = "minecraft:cherry_sapling"
    CherrySign = "minecraft:cherry_sign"
    CherrySlab = "minecraft:cherry_slab"
    CherryStairs = "minecraft:cherry_stairs"
    CherryTrapdoor = "minecraft:cherry_trapdoor"
    CherryWood = "minecraft:cherry_wood"
    Chest = "minecraft:chest"
    ChestMinecart = "minecraft:chest_minecart"
    Chicken = "minecraft:chicken"
    ChickenSpawnEgg = "minecraft:chicken_spawn_egg"
    ChippedAnvil = "minecraft:chipped_anvil"
    ChiseledBookshelf = "minecraft:chiseled_bookshelf"
    ChiseledCopper = "minecraft:chiseled_copper"
    ChiseledDeepslate = "minecraft:chiseled_deepslate"
    ChiseledNetherBricks = "minecraft:chiseled_nether_bricks"
    ChiseledPolishedBlackstone = "minecraft:chiseled_polished_blackstone"
    ChiseledQuartzBlock = "minecraft:chiseled_quartz_block"
    ChiseledRedSandstone = "minecraft:chiseled_red_sandstone"
    ChiseledResinBricks = "minecraft:chiseled_resin_bricks"
    ChiseledSandstone = "minecraft:chiseled_sandstone"
    ChiseledStoneBricks = "minecraft:chiseled_stone_bricks"
    ChiseledTuff = "minecraft:chiseled_tuff"
    ChiseledTuffBricks = "minecraft:chiseled_tuff_bricks"
    ChorusFlower = "minecraft:chorus_flower"
    ChorusFruit = "minecraft:chorus_fruit"
    ChorusPlant = "minecraft:chorus_plant"
    Clay = "minecraft:clay"
    ClayBall = "minecraft:clay_ball"
    Clock = "minecraft:clock"
    ClosedEyeblossom = "minecraft:closed_eyeblossom"
    Coal = "minecraft:coal"
    CoalBlock = "minecraft:coal_block"
    CoalOre = "minecraft:coal_ore"
    CoarseDirt = "minecraft:coarse_dirt"
    CoastArmorTrimSmithingTemplate = "minecraft:coast_armor_trim_smithing_template"
    CobbledDeepslate = "minecraft:cobbled_deepslate"
    CobbledDeepslateSlab = "minecraft:cobbled_deepslate_slab"
    CobbledDeepslateStairs = "minecraft:cobbled_deepslate_stairs"
    CobbledDeepslateWall = "minecraft:cobbled_deepslate_wall"
    Cobblestone = "minecraft:cobblestone"
    CobblestoneSlab = "minecraft:cobblestone_slab"
    CobblestoneWall = "minecraft:cobblestone_wall"
    CocoaBeans = "minecraft:cocoa_beans"
    Cod = "minecraft:cod"
    CodBucket = "minecraft:cod_bucket"
    CodSpawnEgg = "minecraft:cod_spawn_egg"
    CommandBlock = "minecraft:command_block"
    CommandBlockMinecart = "minecraft:command_block_minecart"
    Comparator = "minecraft:comparator"
    Compass = "minecraft:compass"
    Composter = "minecraft:composter"
    Conduit = "minecraft:conduit"
    CookedBeef = "minecraft:cooked_beef"
    CookedChicken = "minecraft:cooked_chicken"
    CookedCod = "minecraft:cooked_cod"
    CookedMutton = "minecraft:cooked_mutton"
    CookedPorkchop = "minecraft:cooked_porkchop"
    CookedRabbit = "minecraft:cooked_rabbit"
    CookedSalmon = "minecraft:cooked_salmon"
    Cookie = "minecraft:cookie"
    CopperBlock = "minecraft:copper_block"
    CopperBulb = "minecraft:copper_bulb"
    CopperDoor = "minecraft:copper_door"
    CopperGrate = "minecraft:copper_grate"
    CopperIngot = "minecraft:copper_ingot"
    CopperOre = "minecraft:copper_ore"
    CopperTrapdoor = "minecraft:copper_trapdoor"
    Cornflower = "minecraft:cornflower"
    CowSpawnEgg = "minecraft:cow_spawn_egg"
    CrackedDeepslateBricks = "minecraft:cracked_deepslate_bricks"
    CrackedDeepslateTiles = "minecraft:cracked_deepslate_tiles"
    CrackedNetherBricks = "minecraft:cracked_nether_bricks"
    CrackedPolishedBlackstoneBricks = "minecraft:cracked_polished_blackstone_bricks"
    CrackedStoneBricks = "minecraft:cracked_stone_bricks"
    Crafter = "minecraft:crafter"
    CraftingTable = "minecraft:crafting_table"
    CreakingHeart = "minecraft:creaking_heart"
    CreakingSpawnEgg = "minecraft:creaking_spawn_egg"
    CreeperBannerPattern = "minecraft:creeper_banner_pattern"
    CreeperHead = "minecraft:creeper_head"
    CreeperSpawnEgg = "minecraft:creeper_spawn_egg"
    CrimsonButton = "minecraft:crimson_button"
    CrimsonDoor = "minecraft:crimson_door"
    CrimsonFence = "minecraft:crimson_fence"
    CrimsonFenceGate = "minecraft:crimson_fence_gate"
    CrimsonFungus = "minecraft:crimson_fungus"
    CrimsonHangingSign = "minecraft:crimson_hanging_sign"
    CrimsonHyphae = "minecraft:crimson_hyphae"
    CrimsonNylium = "minecraft:crimson_nylium"
    CrimsonPlanks = "minecraft:crimson_planks"
    CrimsonPressurePlate = "minecraft:crimson_pressure_plate"
    CrimsonRoots = "minecraft:crimson_roots"
    CrimsonSign = "minecraft:crimson_sign"
    CrimsonSlab = "minecraft:crimson_slab"
    CrimsonStairs = "minecraft:crimson_stairs"
    CrimsonStem = "minecraft:crimson_stem"
    CrimsonTrapdoor = "minecraft:crimson_trapdoor"
    Crossbow = "minecraft:crossbow"
    CryingObsidian = "minecraft:crying_obsidian"
    CutCopper = "minecraft:cut_copper"
    CutCopperSlab = "minecraft:cut_copper_slab"
    CutCopperStairs = "minecraft:cut_copper_stairs"
    CutRedSandstone = "minecraft:cut_red_sandstone"
    CutRedSandstoneSlab = "minecraft:cut_red_sandstone_slab"
    CutSandstone = "minecraft:cut_sandstone"
    CutSandstoneSlab = "minecraft:cut_sandstone_slab"
    CyanBundle = "minecraft:cyan_bundle"
    CyanCandle = "minecraft:cyan_candle"
    CyanCarpet = "minecraft:cyan_carpet"
    CyanConcrete = "minecraft:cyan_concrete"
    CyanConcretePowder = "minecraft:cyan_concrete_powder"
    CyanDye = "minecraft:cyan_dye"
    CyanGlazedTerracotta = "minecraft:cyan_glazed_terracotta"
    CyanHarness = "minecraft:cyan_harness"
    CyanShulkerBox = "minecraft:cyan_shulker_box"
    CyanStainedGlass = "minecraft:cyan_stained_glass"
    CyanStainedGlassPane = "minecraft:cyan_stained_glass_pane"
    CyanTerracotta = "minecraft:cyan_terracotta"
    CyanWool = "minecraft:cyan_wool"
    DamagedAnvil = "minecraft:damaged_anvil"
    Dandelion = "minecraft:dandelion"
    DangerPotterySherd = "minecraft:danger_pottery_sherd"
    DarkOakBoat = "minecraft:dark_oak_boat"
    DarkOakButton = "minecraft:dark_oak_button"
    DarkOakChestBoat = "minecraft:dark_oak_chest_boat"
    DarkOakDoor = "minecraft:dark_oak_door"
    DarkOakFence = "minecraft:dark_oak_fence"
    DarkOakFenceGate = "minecraft:dark_oak_fence_gate"
    DarkOakHangingSign = "minecraft:dark_oak_hanging_sign"
    DarkOakLeaves = "minecraft:dark_oak_leaves"
    DarkOakLog = "minecraft:dark_oak_log"
    DarkOakPlanks = "minecraft:dark_oak_planks"
    DarkOakPressurePlate = "minecraft:dark_oak_pressure_plate"
    DarkOakSapling = "minecraft:dark_oak_sapling"
    DarkOakSign = "minecraft:dark_oak_sign"
    DarkOakSlab = "minecraft:dark_oak_slab"
    DarkOakStairs = "minecraft:dark_oak_stairs"
    DarkOakTrapdoor = "minecraft:dark_oak_trapdoor"
    DarkOakWood = "minecraft:dark_oak_wood"
    DarkPrismarine = "minecraft:dark_prismarine"
    DarkPrismarineSlab = "minecraft:dark_prismarine_slab"
    DarkPrismarineStairs = "minecraft:dark_prismarine_stairs"
    DaylightDetector = "minecraft:daylight_detector"
    DeadBrainCoral = "minecraft:dead_brain_coral"
    DeadBrainCoralBlock = "minecraft:dead_brain_coral_block"
    DeadBrainCoralFan = "minecraft:dead_brain_coral_fan"
    DeadBubbleCoral = "minecraft:dead_bubble_coral"
    DeadBubbleCoralBlock = "minecraft:dead_bubble_coral_block"
    DeadBubbleCoralFan = "minecraft:dead_bubble_coral_fan"
    DeadFireCoral = "minecraft:dead_fire_coral"
    DeadFireCoralBlock = "minecraft:dead_fire_coral_block"
    DeadFireCoralFan = "minecraft:dead_fire_coral_fan"
    DeadHornCoral = "minecraft:dead_horn_coral"
    DeadHornCoralBlock = "minecraft:dead_horn_coral_block"
    DeadHornCoralFan = "minecraft:dead_horn_coral_fan"
    DeadTubeCoral = "minecraft:dead_tube_coral"
    DeadTubeCoralBlock = "minecraft:dead_tube_coral_block"
    DeadTubeCoralFan = "minecraft:dead_tube_coral_fan"
    Deadbush = "minecraft:deadbush"
    DecoratedPot = "minecraft:decorated_pot"
    Deepslate = "minecraft:deepslate"
    DeepslateBrickSlab = "minecraft:deepslate_brick_slab"
    DeepslateBrickStairs = "minecraft:deepslate_brick_stairs"
    DeepslateBrickWall = "minecraft:deepslate_brick_wall"
    DeepslateBricks = "minecraft:deepslate_bricks"
    DeepslateCoalOre = "minecraft:deepslate_coal_ore"
    DeepslateCopperOre = "minecraft:deepslate_copper_ore"
    DeepslateDiamondOre = "minecraft:deepslate_diamond_ore"
    DeepslateEmeraldOre = "minecraft:deepslate_emerald_ore"
    DeepslateGoldOre = "minecraft:deepslate_gold_ore"
    DeepslateIronOre = "minecraft:deepslate_iron_ore"
    DeepslateLapisOre = "minecraft:deepslate_lapis_ore"
    DeepslateRedstoneOre = "minecraft:deepslate_redstone_ore"
    DeepslateTileSlab = "minecraft:deepslate_tile_slab"
    DeepslateTileStairs = "minecraft:deepslate_tile_stairs"
    DeepslateTileWall = "minecraft:deepslate_tile_wall"
    DeepslateTiles = "minecraft:deepslate_tiles"
    Deny = "minecraft:deny"
    DetectorRail = "minecraft:detector_rail"
    Diamond = "minecraft:diamond"
    DiamondAxe = "minecraft:diamond_axe"
    DiamondBlock = "minecraft:diamond_block"
    DiamondBoots = "minecraft:diamond_boots"
    DiamondChestplate = "minecraft:diamond_chestplate"
    DiamondHelmet = "minecraft:diamond_helmet"
    DiamondHoe = "minecraft:diamond_hoe"
    DiamondHorseArmor = "minecraft:diamond_horse_armor"
    DiamondLeggings = "minecraft:diamond_leggings"
    DiamondOre = "minecraft:diamond_ore"
    DiamondPickaxe = "minecraft:diamond_pickaxe"
    DiamondShovel = "minecraft:diamond_shovel"
    DiamondSword = "minecraft:diamond_sword"
    Diorite = "minecraft:diorite"
    DioriteSlab = "minecraft:diorite_slab"
    DioriteStairs = "minecraft:diorite_stairs"
    DioriteWall = "minecraft:diorite_wall"
    Dirt = "minecraft:dirt"
    DirtWithRoots = "minecraft:dirt_with_roots"
    DiscFragment5 = "minecraft:disc_fragment_5"
    Dispenser = "minecraft:dispenser"
    DolphinSpawnEgg = "minecraft:dolphin_spawn_egg"
    DonkeySpawnEgg = "minecraft:donkey_spawn_egg"
    DragonBreath = "minecraft:dragon_breath"
    DragonEgg = "minecraft:dragon_egg"
    DragonHead = "minecraft:dragon_head"
    DriedGhast = "minecraft:dried_ghast"
    DriedKelp = "minecraft:dried_kelp"
    DriedKelpBlock = "minecraft:dried_kelp_block"
    DripstoneBlock = "minecraft:dripstone_block"
    Dropper = "minecraft:dropper"
    DrownedSpawnEgg = "minecraft:drowned_spawn_egg"
    DuneArmorTrimSmithingTemplate = "minecraft:dune_armor_trim_smithing_template"
    EchoShard = "minecraft:echo_shard"
    Egg = "minecraft:egg"
    ElderGuardianSpawnEgg = "minecraft:elder_guardian_spawn_egg"
    Elytra = "minecraft:elytra"
    Emerald = "minecraft:emerald"
    EmeraldBlock = "minecraft:emerald_block"
    EmeraldOre = "minecraft:emerald_ore"
    EmptyMap = "minecraft:empty_map"
    EnchantedBook = "minecraft:enchanted_book"
    EnchantedGoldenApple = "minecraft:enchanted_golden_apple"
    EnchantingTable = "minecraft:enchanting_table"
    EndBrickStairs = "minecraft:end_brick_stairs"
    EndBricks = "minecraft:end_bricks"
    EndCrystal = "minecraft:end_crystal"
    EndPortalFrame = "minecraft:end_portal_frame"
    EndRod = "minecraft:end_rod"
    EndStone = "minecraft:end_stone"
    EndStoneBrickSlab = "minecraft:end_stone_brick_slab"
    EndStoneBrickWall = "minecraft:end_stone_brick_wall"
    EnderChest = "minecraft:ender_chest"
    EnderDragonSpawnEgg = "minecraft:ender_dragon_spawn_egg"
    EnderEye = "minecraft:ender_eye"
    EnderPearl = "minecraft:ender_pearl"
    EndermanSpawnEgg = "minecraft:enderman_spawn_egg"
    EndermiteSpawnEgg = "minecraft:endermite_spawn_egg"
    EvokerSpawnEgg = "minecraft:evoker_spawn_egg"
    ExperienceBottle = "minecraft:experience_bottle"
    ExplorerPotterySherd = "minecraft:explorer_pottery_sherd"
    ExposedChiseledCopper = "minecraft:exposed_chiseled_copper"
    ExposedCopper = "minecraft:exposed_copper"
    ExposedCopperBulb = "minecraft:exposed_copper_bulb"
    ExposedCopperDoor = "minecraft:exposed_copper_door"
    ExposedCopperGrate = "minecraft:exposed_copper_grate"
    ExposedCopperTrapdoor = "minecraft:exposed_copper_trapdoor"
    ExposedCutCopper = "minecraft:exposed_cut_copper"
    ExposedCutCopperSlab = "minecraft:exposed_cut_copper_slab"
    ExposedCutCopperStairs = "minecraft:exposed_cut_copper_stairs"
    EyeArmorTrimSmithingTemplate = "minecraft:eye_armor_trim_smithing_template"
    Farmland = "minecraft:farmland"
    Feather = "minecraft:feather"
    FenceGate = "minecraft:fence_gate"
    FermentedSpiderEye = "minecraft:fermented_spider_eye"
    Fern = "minecraft:fern"
    FieldMasonedBannerPattern = "minecraft:field_masoned_banner_pattern"
    FilledMap = "minecraft:filled_map"
    FireCharge = "minecraft:fire_charge"
    FireCoral = "minecraft:fire_coral"
    FireCoralBlock = "minecraft:fire_coral_block"
    FireCoralFan = "minecraft:fire_coral_fan"
    FireflyBush = "minecraft:firefly_bush"
    FireworkRocket = "minecraft:firework_rocket"
    FireworkStar = "minecraft:firework_star"
    FishingRod = "minecraft:fishing_rod"
    FletchingTable = "minecraft:fletching_table"
    Flint = "minecraft:flint"
    FlintAndSteel = "minecraft:flint_and_steel"
    FlowArmorTrimSmithingTemplate = "minecraft:flow_armor_trim_smithing_template"
    FlowBannerPattern = "minecraft:flow_banner_pattern"
    FlowPotterySherd = "minecraft:flow_pottery_sherd"
    FlowerBannerPattern = "minecraft:flower_banner_pattern"
    FlowerPot = "minecraft:flower_pot"
    FloweringAzalea = "minecraft:flowering_azalea"
    FoxSpawnEgg = "minecraft:fox_spawn_egg"
    Frame = "minecraft:frame"
    FriendPotterySherd = "minecraft:friend_pottery_sherd"
    FrogSpawn = "minecraft:frog_spawn"
    FrogSpawnEgg = "minecraft:frog_spawn_egg"
    FrostedIce = "minecraft:frosted_ice"
    Furnace = "minecraft:furnace"
    GhastSpawnEgg = "minecraft:ghast_spawn_egg"
    GhastTear = "minecraft:ghast_tear"
    GildedBlackstone = "minecraft:gilded_blackstone"
    Glass = "minecraft:glass"
    GlassBottle = "minecraft:glass_bottle"
    GlassPane = "minecraft:glass_pane"
    GlisteringMelonSlice = "minecraft:glistering_melon_slice"
    GlobeBannerPattern = "minecraft:globe_banner_pattern"
    GlowBerries = "minecraft:glow_berries"
    GlowFrame = "minecraft:glow_frame"
    GlowInkSac = "minecraft:glow_ink_sac"
    GlowLichen = "minecraft:glow_lichen"
    GlowSquidSpawnEgg = "minecraft:glow_squid_spawn_egg"
    Glowstone = "minecraft:glowstone"
    GlowstoneDust = "minecraft:glowstone_dust"
    GoatHorn = "minecraft:goat_horn"
    GoatSpawnEgg = "minecraft:goat_spawn_egg"
    GoldBlock = "minecraft:gold_block"
    GoldIngot = "minecraft:gold_ingot"
    GoldNugget = "minecraft:gold_nugget"
    GoldOre = "minecraft:gold_ore"
    GoldenApple = "minecraft:golden_apple"
    GoldenAxe = "minecraft:golden_axe"
    GoldenBoots = "minecraft:golden_boots"
    GoldenCarrot = "minecraft:golden_carrot"
    GoldenChestplate = "minecraft:golden_chestplate"
    GoldenHelmet = "minecraft:golden_helmet"
    GoldenHoe = "minecraft:golden_hoe"
    GoldenHorseArmor = "minecraft:golden_horse_armor"
    GoldenLeggings = "minecraft:golden_leggings"
    GoldenPickaxe = "minecraft:golden_pickaxe"
    GoldenRail = "minecraft:golden_rail"
    GoldenShovel = "minecraft:golden_shovel"
    GoldenSword = "minecraft:golden_sword"
    Granite = "minecraft:granite"
    GraniteSlab = "minecraft:granite_slab"
    GraniteStairs = "minecraft:granite_stairs"
    GraniteWall = "minecraft:granite_wall"
    GrassBlock = "minecraft:grass_block"
    GrassPath = "minecraft:grass_path"
    Gravel = "minecraft:gravel"
    GrayBundle = "minecraft:gray_bundle"
    GrayCandle = "minecraft:gray_candle"
    GrayCarpet = "minecraft:gray_carpet"
    GrayConcrete = "minecraft:gray_concrete"
    GrayConcretePowder = "minecraft:gray_concrete_powder"
    GrayDye = "minecraft:gray_dye"
    GrayGlazedTerracotta = "minecraft:gray_glazed_terracotta"
    GrayHarness = "minecraft:gray_harness"
    GrayShulkerBox = "minecraft:gray_shulker_box"
    GrayStainedGlass = "minecraft:gray_stained_glass"
    GrayStainedGlassPane = "minecraft:gray_stained_glass_pane"
    GrayTerracotta = "minecraft:gray_terracotta"
    GrayWool = "minecraft:gray_wool"
    GreenBundle = "minecraft:green_bundle"
    GreenCandle = "minecraft:green_candle"
    GreenCarpet = "minecraft:green_carpet"
    GreenConcrete = "minecraft:green_concrete"
    GreenConcretePowder = "minecraft:green_concrete_powder"
    GreenDye = "minecraft:green_dye"
    GreenGlazedTerracotta = "minecraft:green_glazed_terracotta"
    GreenHarness = "minecraft:green_harness"
    GreenShulkerBox = "minecraft:green_shulker_box"
    GreenStainedGlass = "minecraft:green_stained_glass"
    GreenStainedGlassPane = "minecraft:green_stained_glass_pane"
    GreenTerracotta = "minecraft:green_terracotta"
    GreenWool = "minecraft:green_wool"
    Grindstone = "minecraft:grindstone"
    GuardianSpawnEgg = "minecraft:guardian_spawn_egg"
    Gunpowder = "minecraft:gunpowder"
    GusterBannerPattern = "minecraft:guster_banner_pattern"
    GusterPotterySherd = "minecraft:guster_pottery_sherd"
    HangingRoots = "minecraft:hanging_roots"
    HappyGhastSpawnEgg = "minecraft:happy_ghast_spawn_egg"
    HardenedClay = "minecraft:hardened_clay"
    HayBlock = "minecraft:hay_block"
    HeartOfTheSea = "minecraft:heart_of_the_sea"
    HeartPotterySherd = "minecraft:heart_pottery_sherd"
    HeartbreakPotterySherd = "minecraft:heartbreak_pottery_sherd"
    HeavyCore = "minecraft:heavy_core"
    HeavyWeightedPressurePlate = "minecraft:heavy_weighted_pressure_plate"
    HoglinSpawnEgg = "minecraft:hoglin_spawn_egg"
    HoneyBlock = "minecraft:honey_block"
    HoneyBottle = "minecraft:honey_bottle"
    Honeycomb = "minecraft:honeycomb"
    HoneycombBlock = "minecraft:honeycomb_block"
    Hopper = "minecraft:hopper"
    HopperMinecart = "minecraft:hopper_minecart"
    HornCoral = "minecraft:horn_coral"
    HornCoralBlock = "minecraft:horn_coral_block"
    HornCoralFan = "minecraft:horn_coral_fan"
    HorseSpawnEgg = "minecraft:horse_spawn_egg"
    HostArmorTrimSmithingTemplate = "minecraft:host_armor_trim_smithing_template"
    HowlPotterySherd = "minecraft:howl_pottery_sherd"
    HuskSpawnEgg = "minecraft:husk_spawn_egg"
    Ice = "minecraft:ice"
    InfestedChiseledStoneBricks = "minecraft:infested_chiseled_stone_bricks"
    InfestedCobblestone = "minecraft:infested_cobblestone"
    InfestedCrackedStoneBricks = "minecraft:infested_cracked_stone_bricks"
    InfestedDeepslate = "minecraft:infested_deepslate"
    InfestedMossyStoneBricks = "minecraft:infested_mossy_stone_bricks"
    InfestedStone = "minecraft:infested_stone"
    InfestedStoneBricks = "minecraft:infested_stone_bricks"
    InkSac = "minecraft:ink_sac"
    IronAxe = "minecraft:iron_axe"
    IronBars = "minecraft:iron_bars"
    IronBlock = "minecraft:iron_block"
    IronBoots = "minecraft:iron_boots"
    IronChestplate = "minecraft:iron_chestplate"
    IronDoor = "minecraft:iron_door"
    IronGolemSpawnEgg = "minecraft:iron_golem_spawn_egg"
    IronHelmet = "minecraft:iron_helmet"
    IronHoe = "minecraft:iron_hoe"
    IronHorseArmor = "minecraft:iron_horse_armor"
    IronIngot = "minecraft:iron_ingot"
    IronLeggings = "minecraft:iron_leggings"
    IronNugget = "minecraft:iron_nugget"
    IronOre = "minecraft:iron_ore"
    IronPickaxe = "minecraft:iron_pickaxe"
    IronShovel = "minecraft:iron_shovel"
    IronSword = "minecraft:iron_sword"
    IronTrapdoor = "minecraft:iron_trapdoor"
    Jigsaw = "minecraft:jigsaw"
    Jukebox = "minecraft:jukebox"
    JungleBoat = "minecraft:jungle_boat"
    JungleButton = "minecraft:jungle_button"
    JungleChestBoat = "minecraft:jungle_chest_boat"
    JungleDoor = "minecraft:jungle_door"
    JungleFence = "minecraft:jungle_fence"
    JungleFenceGate = "minecraft:jungle_fence_gate"
    JungleHangingSign = "minecraft:jungle_hanging_sign"
    JungleLeaves = "minecraft:jungle_leaves"
    JungleLog = "minecraft:jungle_log"
    JunglePlanks = "minecraft:jungle_planks"
    JunglePressurePlate = "minecraft:jungle_pressure_plate"
    JungleSapling = "minecraft:jungle_sapling"
    JungleSign = "minecraft:jungle_sign"
    JungleSlab = "minecraft:jungle_slab"
    JungleStairs = "minecraft:jungle_stairs"
    JungleTrapdoor = "minecraft:jungle_trapdoor"
    JungleWood = "minecraft:jungle_wood"
    Kelp = "minecraft:kelp"
    Ladder = "minecraft:ladder"
    Lantern = "minecraft:lantern"
    LapisBlock = "minecraft:lapis_block"
    LapisLazuli = "minecraft:lapis_lazuli"
    LapisOre = "minecraft:lapis_ore"
    LargeAmethystBud = "minecraft:large_amethyst_bud"
    LargeFern = "minecraft:large_fern"
    LavaBucket = "minecraft:lava_bucket"
    Lead = "minecraft:lead"
    LeafLitter = "minecraft:leaf_litter"
    Leather = "minecraft:leather"
    LeatherBoots = "minecraft:leather_boots"
    LeatherChestplate = "minecraft:leather_chestplate"
    LeatherHelmet = "minecraft:leather_helmet"
    LeatherHorseArmor = "minecraft:leather_horse_armor"
    LeatherLeggings = "minecraft:leather_leggings"
    Lectern = "minecraft:lectern"
    Lever = "minecraft:lever"
    LightBlock0 = "minecraft:light_block_0"
    LightBlock1 = "minecraft:light_block_1"
    LightBlock10 = "minecraft:light_block_10"
    LightBlock11 = "minecraft:light_block_11"
    LightBlock12 = "minecraft:light_block_12"
    LightBlock13 = "minecraft:light_block_13"
    LightBlock14 = "minecraft:light_block_14"
    LightBlock15 = "minecraft:light_block_15"
    LightBlock2 = "minecraft:light_block_2"
    LightBlock3 = "minecraft:light_block_3"
    LightBlock4 = "minecraft:light_block_4"
    LightBlock5 = "minecraft:light_block_5"
    LightBlock6 = "minecraft:light_block_6"
    LightBlock7 = "minecraft:light_block_7"
    LightBlock8 = "minecraft:light_block_8"
    LightBlock9 = "minecraft:light_block_9"
    LightBlueBundle = "minecraft:light_blue_bundle"
    LightBlueCandle = "minecraft:light_blue_candle"
    LightBlueCarpet = "minecraft:light_blue_carpet"
    LightBlueConcrete = "minecraft:light_blue_concrete"
    LightBlueConcretePowder = "minecraft:light_blue_concrete_powder"
    LightBlueDye = "minecraft:light_blue_dye"
    LightBlueGlazedTerracotta = "minecraft:light_blue_glazed_terracotta"
    LightBlueHarness = "minecraft:light_blue_harness"
    LightBlueShulkerBox = "minecraft:light_blue_shulker_box"
    LightBlueStainedGlass = "minecraft:light_blue_stained_glass"
    LightBlueStainedGlassPane = "minecraft:light_blue_stained_glass_pane"
    LightBlueTerracotta = "minecraft:light_blue_terracotta"
    LightBlueWool = "minecraft:light_blue_wool"
    LightGrayBundle = "minecraft:light_gray_bundle"
    LightGrayCandle = "minecraft:light_gray_candle"
    LightGrayCarpet = "minecraft:light_gray_carpet"
    LightGrayConcrete = "minecraft:light_gray_concrete"
    LightGrayConcretePowder = "minecraft:light_gray_concrete_powder"
    LightGrayDye = "minecraft:light_gray_dye"
    LightGrayHarness = "minecraft:light_gray_harness"
    LightGrayShulkerBox = "minecraft:light_gray_shulker_box"
    LightGrayStainedGlass = "minecraft:light_gray_stained_glass"
    LightGrayStainedGlassPane = "minecraft:light_gray_stained_glass_pane"
    LightGrayTerracotta = "minecraft:light_gray_terracotta"
    LightGrayWool = "minecraft:light_gray_wool"
    LightWeightedPressurePlate = "minecraft:light_weighted_pressure_plate"
    LightningRod = "minecraft:lightning_rod"
    Lilac = "minecraft:lilac"
    LilyOfTheValley = "minecraft:lily_of_the_valley"
    LimeBundle = "minecraft:lime_bundle"
    LimeCandle = "minecraft:lime_candle"
    LimeCarpet = "minecraft:lime_carpet"
    LimeConcrete = "minecraft:lime_concrete"
    LimeConcretePowder = "minecraft:lime_concrete_powder"
    LimeDye = "minecraft:lime_dye"
    LimeGlazedTerracotta = "minecraft:lime_glazed_terracotta"
    LimeHarness = "minecraft:lime_harness"
    LimeShulkerBox = "minecraft:lime_shulker_box"
    LimeStainedGlass = "minecraft:lime_stained_glass"
    LimeStainedGlassPane = "minecraft:lime_stained_glass_pane"
    LimeTerracotta = "minecraft:lime_terracotta"
    LimeWool = "minecraft:lime_wool"
    LingeringPotion = "minecraft:lingering_potion"
    LitPumpkin = "minecraft:lit_pumpkin"
    LlamaSpawnEgg = "minecraft:llama_spawn_egg"
    Lodestone = "minecraft:lodestone"
    LodestoneCompass = "minecraft:lodestone_compass"
    Loom = "minecraft:loom"
    Mace = "minecraft:mace"
    MagentaBundle = "minecraft:magenta_bundle"
    MagentaCandle = "minecraft:magenta_candle"
    MagentaCarpet = "minecraft:magenta_carpet"
    MagentaConcrete = "minecraft:magenta_concrete"
    MagentaConcretePowder = "minecraft:magenta_concrete_powder"
    MagentaDye = "minecraft:magenta_dye"
    MagentaGlazedTerracotta = "minecraft:magenta_glazed_terracotta"
    MagentaHarness = "minecraft:magenta_harness"
    MagentaShulkerBox = "minecraft:magenta_shulker_box"
    MagentaStainedGlass = "minecraft:magenta_stained_glass"
    MagentaStainedGlassPane = "minecraft:magenta_stained_glass_pane"
    MagentaTerracotta = "minecraft:magenta_terracotta"
    MagentaWool = "minecraft:magenta_wool"
    Magma = "minecraft:magma"
    MagmaCream = "minecraft:magma_cream"
    MagmaCubeSpawnEgg = "minecraft:magma_cube_spawn_egg"
    MangroveBoat = "minecraft:mangrove_boat"
    MangroveButton = "minecraft:mangrove_button"
    MangroveChestBoat = "minecraft:mangrove_chest_boat"
    MangroveDoor = "minecraft:mangrove_door"
    MangroveFence = "minecraft:mangrove_fence"
    MangroveFenceGate = "minecraft:mangrove_fence_gate"
    MangroveHangingSign = "minecraft:mangrove_hanging_sign"
    MangroveLeaves = "minecraft:mangrove_leaves"
    MangroveLog = "minecraft:mangrove_log"
    MangrovePlanks = "minecraft:mangrove_planks"
    MangrovePressurePlate = "minecraft:mangrove_pressure_plate"
    MangrovePropagule = "minecraft:mangrove_propagule"
    MangroveRoots = "minecraft:mangrove_roots"
    MangroveSign = "minecraft:mangrove_sign"
    MangroveSlab = "minecraft:mangrove_slab"
    MangroveStairs = "minecraft:mangrove_stairs"
    MangroveTrapdoor = "minecraft:mangrove_trapdoor"
    MangroveWood = "minecraft:mangrove_wood"
    MediumAmethystBud = "minecraft:medium_amethyst_bud"
    MelonBlock = "minecraft:melon_block"
    MelonSeeds = "minecraft:melon_seeds"
    MelonSlice = "minecraft:melon_slice"
    MilkBucket = "minecraft:milk_bucket"
    Minecart = "minecraft:minecart"
    MinerPotterySherd = "minecraft:miner_pottery_sherd"
    MobSpawner = "minecraft:mob_spawner"
    MojangBannerPattern = "minecraft:mojang_banner_pattern"
    MooshroomSpawnEgg = "minecraft:mooshroom_spawn_egg"
    MossBlock = "minecraft:moss_block"
    MossCarpet = "minecraft:moss_carpet"
    MossyCobblestone = "minecraft:mossy_cobblestone"
    MossyCobblestoneSlab = "minecraft:mossy_cobblestone_slab"
    MossyCobblestoneStairs = "minecraft:mossy_cobblestone_stairs"
    MossyCobblestoneWall = "minecraft:mossy_cobblestone_wall"
    MossyStoneBrickSlab = "minecraft:mossy_stone_brick_slab"
    MossyStoneBrickStairs = "minecraft:mossy_stone_brick_stairs"
    MossyStoneBrickWall = "minecraft:mossy_stone_brick_wall"
    MossyStoneBricks = "minecraft:mossy_stone_bricks"
    MournerPotterySherd = "minecraft:mourner_pottery_sherd"
    Mud = "minecraft:mud"
    MudBrickSlab = "minecraft:mud_brick_slab"
    MudBrickStairs = "minecraft:mud_brick_stairs"
    MudBrickWall = "minecraft:mud_brick_wall"
    MudBricks = "minecraft:mud_bricks"
    MuddyMangroveRoots = "minecraft:muddy_mangrove_roots"
    MuleSpawnEgg = "minecraft:mule_spawn_egg"
    MushroomStem = "minecraft:mushroom_stem"
    MushroomStew = "minecraft:mushroom_stew"
    MusicDisc11 = "minecraft:music_disc_11"
    MusicDisc13 = "minecraft:music_disc_13"
    MusicDisc5 = "minecraft:music_disc_5"
    MusicDiscBlocks = "minecraft:music_disc_blocks"
    MusicDiscCat = "minecraft:music_disc_cat"
    MusicDiscChirp = "minecraft:music_disc_chirp"
    MusicDiscCreator = "minecraft:music_disc_creator"
    MusicDiscCreatorMusicBox = "minecraft:music_disc_creator_music_box"
    MusicDiscFar = "minecraft:music_disc_far"
    MusicDiscMall = "minecraft:music_disc_mall"
    MusicDiscMellohi = "minecraft:music_disc_mellohi"
    MusicDiscOtherside = "minecraft:music_disc_otherside"
    MusicDiscPigstep = "minecraft:music_disc_pigstep"
    MusicDiscPrecipice = "minecraft:music_disc_precipice"
    MusicDiscRelic = "minecraft:music_disc_relic"
    MusicDiscStal = "minecraft:music_disc_stal"
    MusicDiscStrad = "minecraft:music_disc_strad"
    MusicDiscWait = "minecraft:music_disc_wait"
    MusicDiscWard = "minecraft:music_disc_ward"
    Mutton = "minecraft:mutton"
    Mycelium = "minecraft:mycelium"
    NameTag = "minecraft:name_tag"
    NautilusShell = "minecraft:nautilus_shell"
    NetherBrick = "minecraft:nether_brick"
    NetherBrickFence = "minecraft:nether_brick_fence"
    NetherBrickSlab = "minecraft:nether_brick_slab"
    NetherBrickStairs = "minecraft:nether_brick_stairs"
    NetherBrickWall = "minecraft:nether_brick_wall"
    NetherGoldOre = "minecraft:nether_gold_ore"
    NetherSprouts = "minecraft:nether_sprouts"
    NetherStar = "minecraft:nether_star"
    NetherWart = "minecraft:nether_wart"
    NetherWartBlock = "minecraft:nether_wart_block"
    Netherbrick = "minecraft:netherbrick"
    NetheriteAxe = "minecraft:netherite_axe"
    NetheriteBlock = "minecraft:netherite_block"
    NetheriteBoots = "minecraft:netherite_boots"
    NetheriteChestplate = "minecraft:netherite_chestplate"
    NetheriteHelmet = "minecraft:netherite_helmet"
    NetheriteHoe = "minecraft:netherite_hoe"
    NetheriteIngot = "minecraft:netherite_ingot"
    NetheriteLeggings = "minecraft:netherite_leggings"
    NetheritePickaxe = "minecraft:netherite_pickaxe"
    NetheriteScrap = "minecraft:netherite_scrap"
    NetheriteShovel = "minecraft:netherite_shovel"
    NetheriteSword = "minecraft:netherite_sword"
    NetheriteUpgradeSmithingTemplate = "minecraft:netherite_upgrade_smithing_template"
    Netherrack = "minecraft:netherrack"
    NormalStoneSlab = "minecraft:normal_stone_slab"
    NormalStoneStairs = "minecraft:normal_stone_stairs"
    Noteblock = "minecraft:noteblock"
    OakBoat = "minecraft:oak_boat"
    OakChestBoat = "minecraft:oak_chest_boat"
    OakFence = "minecraft:oak_fence"
    OakHangingSign = "minecraft:oak_hanging_sign"
    OakLeaves = "minecraft:oak_leaves"
    OakLog = "minecraft:oak_log"
    OakPlanks = "minecraft:oak_planks"
    OakSapling = "minecraft:oak_sapling"
    OakSign = "minecraft:oak_sign"
    OakSlab = "minecraft:oak_slab"
    OakStairs = "minecraft:oak_stairs"
    OakWood = "minecraft:oak_wood"
    Observer = "minecraft:observer"
    Obsidian = "minecraft:obsidian"
    OcelotSpawnEgg = "minecraft:ocelot_spawn_egg"
    OchreFroglight = "minecraft:ochre_froglight"
    OminousBottle = "minecraft:ominous_bottle"
    OminousTrialKey = "minecraft:ominous_trial_key"
    OpenEyeblossom = "minecraft:open_eyeblossom"
    OrangeBundle = "minecraft:orange_bundle"
    OrangeCandle = "minecraft:orange_candle"
    OrangeCarpet = "minecraft:orange_carpet"
    OrangeConcrete = "minecraft:orange_concrete"
    OrangeConcretePowder = "minecraft:orange_concrete_powder"
    OrangeDye = "minecraft:orange_dye"
    OrangeGlazedTerracotta = "minecraft:orange_glazed_terracotta"
    OrangeHarness = "minecraft:orange_harness"
    OrangeShulkerBox = "minecraft:orange_shulker_box"
    OrangeStainedGlass = "minecraft:orange_stained_glass"
    OrangeStainedGlassPane = "minecraft:orange_stained_glass_pane"
    OrangeTerracotta = "minecraft:orange_terracotta"
    OrangeTulip = "minecraft:orange_tulip"
    OrangeWool = "minecraft:orange_wool"
    OxeyeDaisy = "minecraft:oxeye_daisy"
    OxidizedChiseledCopper = "minecraft:oxidized_chiseled_copper"
    OxidizedCopper = "minecraft:oxidized_copper"
    OxidizedCopperBulb = "minecraft:oxidized_copper_bulb"
    OxidizedCopperDoor = "minecraft:oxidized_copper_door"
    OxidizedCopperGrate = "minecraft:oxidized_copper_grate"
    OxidizedCopperTrapdoor = "minecraft:oxidized_copper_trapdoor"
    OxidizedCutCopper = "minecraft:oxidized_cut_copper"
    OxidizedCutCopperSlab = "minecraft:oxidized_cut_copper_slab"
    OxidizedCutCopperStairs = "minecraft:oxidized_cut_copper_stairs"
    PackedIce = "minecraft:packed_ice"
    PackedMud = "minecraft:packed_mud"
    Painting = "minecraft:painting"
    PaleHangingMoss = "minecraft:pale_hanging_moss"
    PaleMossBlock = "minecraft:pale_moss_block"
    PaleMossCarpet = "minecraft:pale_moss_carpet"
    PaleOakBoat = "minecraft:pale_oak_boat"
    PaleOakButton = "minecraft:pale_oak_button"
    PaleOakChestBoat = "minecraft:pale_oak_chest_boat"
    PaleOakDoor = "minecraft:pale_oak_door"
    PaleOakFence = "minecraft:pale_oak_fence"
    PaleOakFenceGate = "minecraft:pale_oak_fence_gate"
    PaleOakHangingSign = "minecraft:pale_oak_hanging_sign"
    PaleOakLeaves = "minecraft:pale_oak_leaves"
    PaleOakLog = "minecraft:pale_oak_log"
    PaleOakPlanks = "minecraft:pale_oak_planks"
    PaleOakPressurePlate = "minecraft:pale_oak_pressure_plate"
    PaleOakSapling = "minecraft:pale_oak_sapling"
    PaleOakSign = "minecraft:pale_oak_sign"
    PaleOakSlab = "minecraft:pale_oak_slab"
    PaleOakStairs = "minecraft:pale_oak_stairs"
    PaleOakTrapdoor = "minecraft:pale_oak_trapdoor"
    PaleOakWood = "minecraft:pale_oak_wood"
    PandaSpawnEgg = "minecraft:panda_spawn_egg"
    Paper = "minecraft:paper"
    ParrotSpawnEgg = "minecraft:parrot_spawn_egg"
    PearlescentFroglight = "minecraft:pearlescent_froglight"
    Peony = "minecraft:peony"
    PetrifiedOakSlab = "minecraft:petrified_oak_slab"
    PhantomMembrane = "minecraft:phantom_membrane"
    PhantomSpawnEgg = "minecraft:phantom_spawn_egg"
    PigSpawnEgg = "minecraft:pig_spawn_egg"
    PiglinBannerPattern = "minecraft:piglin_banner_pattern"
    PiglinBruteSpawnEgg = "minecraft:piglin_brute_spawn_egg"
    PiglinHead = "minecraft:piglin_head"
    PiglinSpawnEgg = "minecraft:piglin_spawn_egg"
    PillagerSpawnEgg = "minecraft:pillager_spawn_egg"
    PinkBundle = "minecraft:pink_bundle"
    PinkCandle = "minecraft:pink_candle"
    PinkCarpet = "minecraft:pink_carpet"
    PinkConcrete = "minecraft:pink_concrete"
    PinkConcretePowder = "minecraft:pink_concrete_powder"
    PinkDye = "minecraft:pink_dye"
    PinkGlazedTerracotta = "minecraft:pink_glazed_terracotta"
    PinkHarness = "minecraft:pink_harness"
    PinkPetals = "minecraft:pink_petals"
    PinkShulkerBox = "minecraft:pink_shulker_box"
    PinkStainedGlass = "minecraft:pink_stained_glass"
    PinkStainedGlassPane = "minecraft:pink_stained_glass_pane"
    PinkTerracotta = "minecraft:pink_terracotta"
    PinkTulip = "minecraft:pink_tulip"
    PinkWool = "minecraft:pink_wool"
    Piston = "minecraft:piston"
    PitcherPlant = "minecraft:pitcher_plant"
    PitcherPod = "minecraft:pitcher_pod"
    PlayerHead = "minecraft:player_head"
    PlentyPotterySherd = "minecraft:plenty_pottery_sherd"
    Podzol = "minecraft:podzol"
    PointedDripstone = "minecraft:pointed_dripstone"
    PoisonousPotato = "minecraft:poisonous_potato"
    PolarBearSpawnEgg = "minecraft:polar_bear_spawn_egg"
    PolishedAndesite = "minecraft:polished_andesite"
    PolishedAndesiteSlab = "minecraft:polished_andesite_slab"
    PolishedAndesiteStairs = "minecraft:polished_andesite_stairs"
    PolishedBasalt = "minecraft:polished_basalt"
    PolishedBlackstone = "minecraft:polished_blackstone"
    PolishedBlackstoneBrickSlab = "minecraft:polished_blackstone_brick_slab"
    PolishedBlackstoneBrickStairs = "minecraft:polished_blackstone_brick_stairs"
    PolishedBlackstoneBrickWall = "minecraft:polished_blackstone_brick_wall"
    PolishedBlackstoneBricks = "minecraft:polished_blackstone_bricks"
    PolishedBlackstoneButton = "minecraft:polished_blackstone_button"
    PolishedBlackstonePressurePlate = "minecraft:polished_blackstone_pressure_plate"
    PolishedBlackstoneSlab = "minecraft:polished_blackstone_slab"
    PolishedBlackstoneStairs = "minecraft:polished_blackstone_stairs"
    PolishedBlackstoneWall = "minecraft:polished_blackstone_wall"
    PolishedDeepslate = "minecraft:polished_deepslate"
    PolishedDeepslateSlab = "minecraft:polished_deepslate_slab"
    PolishedDeepslateStairs = "minecraft:polished_deepslate_stairs"
    PolishedDeepslateWall = "minecraft:polished_deepslate_wall"
    PolishedDiorite = "minecraft:polished_diorite"
    PolishedDioriteSlab = "minecraft:polished_diorite_slab"
    PolishedDioriteStairs = "minecraft:polished_diorite_stairs"
    PolishedGranite = "minecraft:polished_granite"
    PolishedGraniteSlab = "minecraft:polished_granite_slab"
    PolishedGraniteStairs = "minecraft:polished_granite_stairs"
    PolishedTuff = "minecraft:polished_tuff"
    PolishedTuffSlab = "minecraft:polished_tuff_slab"
    PolishedTuffStairs = "minecraft:polished_tuff_stairs"
    PolishedTuffWall = "minecraft:polished_tuff_wall"
    PoppedChorusFruit = "minecraft:popped_chorus_fruit"
    Poppy = "minecraft:poppy"
    Porkchop = "minecraft:porkchop"
    Potato = "minecraft:potato"
    Potion = "minecraft:potion"
    PowderSnowBucket = "minecraft:powder_snow_bucket"
    Prismarine = "minecraft:prismarine"
    PrismarineBrickSlab = "minecraft:prismarine_brick_slab"
    PrismarineBricks = "minecraft:prismarine_bricks"
    PrismarineBricksStairs = "minecraft:prismarine_bricks_stairs"
    PrismarineCrystals = "minecraft:prismarine_crystals"
    PrismarineShard = "minecraft:prismarine_shard"
    PrismarineSlab = "minecraft:prismarine_slab"
    PrismarineStairs = "minecraft:prismarine_stairs"
    PrismarineWall = "minecraft:prismarine_wall"
    PrizePotterySherd = "minecraft:prize_pottery_sherd"
    Pufferfish = "minecraft:pufferfish"
    PufferfishBucket = "minecraft:pufferfish_bucket"
    PufferfishSpawnEgg = "minecraft:pufferfish_spawn_egg"
    Pumpkin = "minecraft:pumpkin"
    PumpkinPie = "minecraft:pumpkin_pie"
    PumpkinSeeds = "minecraft:pumpkin_seeds"
    PurpleBundle = "minecraft:purple_bundle"
    PurpleCandle = "minecraft:purple_candle"
    PurpleCarpet = "minecraft:purple_carpet"
    PurpleConcrete = "minecraft:purple_concrete"
    PurpleConcretePowder = "minecraft:purple_concrete_powder"
    PurpleDye = "minecraft:purple_dye"
    PurpleGlazedTerracotta = "minecraft:purple_glazed_terracotta"
    PurpleHarness = "minecraft:purple_harness"
    PurpleShulkerBox = "minecraft:purple_shulker_box"
    PurpleStainedGlass = "minecraft:purple_stained_glass"
    PurpleStainedGlassPane = "minecraft:purple_stained_glass_pane"
    PurpleTerracotta = "minecraft:purple_terracotta"
    PurpleWool = "minecraft:purple_wool"
    PurpurBlock = "minecraft:purpur_block"
    PurpurPillar = "minecraft:purpur_pillar"
    PurpurSlab = "minecraft:purpur_slab"
    PurpurStairs = "minecraft:purpur_stairs"
    Quartz = "minecraft:quartz"
    QuartzBlock = "minecraft:quartz_block"
    QuartzBricks = "minecraft:quartz_bricks"
    QuartzOre = "minecraft:quartz_ore"
    QuartzPillar = "minecraft:quartz_pillar"
    QuartzSlab = "minecraft:quartz_slab"
    QuartzStairs = "minecraft:quartz_stairs"
    Rabbit = "minecraft:rabbit"
    RabbitFoot = "minecraft:rabbit_foot"
    RabbitHide = "minecraft:rabbit_hide"
    RabbitSpawnEgg = "minecraft:rabbit_spawn_egg"
    RabbitStew = "minecraft:rabbit_stew"
    Rail = "minecraft:rail"
    RaiserArmorTrimSmithingTemplate = "minecraft:raiser_armor_trim_smithing_template"
    RavagerSpawnEgg = "minecraft:ravager_spawn_egg"
    RawCopper = "minecraft:raw_copper"
    RawCopperBlock = "minecraft:raw_copper_block"
    RawGold = "minecraft:raw_gold"
    RawGoldBlock = "minecraft:raw_gold_block"
    RawIron = "minecraft:raw_iron"
    RawIronBlock = "minecraft:raw_iron_block"
    RecoveryCompass = "minecraft:recovery_compass"
    RedBundle = "minecraft:red_bundle"
    RedCandle = "minecraft:red_candle"
    RedCarpet = "minecraft:red_carpet"
    RedConcrete = "minecraft:red_concrete"
    RedConcretePowder = "minecraft:red_concrete_powder"
    RedDye = "minecraft:red_dye"
    RedGlazedTerracotta = "minecraft:red_glazed_terracotta"
    RedHarness = "minecraft:red_harness"
    RedMushroom = "minecraft:red_mushroom"
    RedMushroomBlock = "minecraft:red_mushroom_block"
    RedNetherBrick = "minecraft:red_nether_brick"
    RedNetherBrickSlab = "minecraft:red_nether_brick_slab"
    RedNetherBrickStairs = "minecraft:red_nether_brick_stairs"
    RedNetherBrickWall = "minecraft:red_nether_brick_wall"
    RedSand = "minecraft:red_sand"
    RedSandstone = "minecraft:red_sandstone"
    RedSandstoneSlab = "minecraft:red_sandstone_slab"
    RedSandstoneStairs = "minecraft:red_sandstone_stairs"
    RedSandstoneWall = "minecraft:red_sandstone_wall"
    RedShulkerBox = "minecraft:red_shulker_box"
    RedStainedGlass = "minecraft:red_stained_glass"
    RedStainedGlassPane = "minecraft:red_stained_glass_pane"
    RedTerracotta = "minecraft:red_terracotta"
    RedTulip = "minecraft:red_tulip"
    RedWool = "minecraft:red_wool"
    Redstone = "minecraft:redstone"
    RedstoneBlock = "minecraft:redstone_block"
    RedstoneLamp = "minecraft:redstone_lamp"
    RedstoneOre = "minecraft:redstone_ore"
    RedstoneTorch = "minecraft:redstone_torch"
    ReinforcedDeepslate = "minecraft:reinforced_deepslate"
    Repeater = "minecraft:repeater"
    RepeatingCommandBlock = "minecraft:repeating_command_block"
    ResinBlock = "minecraft:resin_block"
    ResinBrick = "minecraft:resin_brick"
    ResinBrickSlab = "minecraft:resin_brick_slab"
    ResinBrickStairs = "minecraft:resin_brick_stairs"
    ResinBrickWall = "minecraft:resin_brick_wall"
    ResinBricks = "minecraft:resin_bricks"
    ResinClump = "minecraft:resin_clump"
    RespawnAnchor = "minecraft:respawn_anchor"
    RibArmorTrimSmithingTemplate = "minecraft:rib_armor_trim_smithing_template"
    RoseBush = "minecraft:rose_bush"
    RottenFlesh = "minecraft:rotten_flesh"
    Saddle = "minecraft:saddle"
    Salmon = "minecraft:salmon"
    SalmonBucket = "minecraft:salmon_bucket"
    SalmonSpawnEgg = "minecraft:salmon_spawn_egg"
    Sand = "minecraft:sand"
    Sandstone = "minecraft:sandstone"
    SandstoneSlab = "minecraft:sandstone_slab"
    SandstoneStairs = "minecraft:sandstone_stairs"
    SandstoneWall = "minecraft:sandstone_wall"
    Scaffolding = "minecraft:scaffolding"
    ScrapePotterySherd = "minecraft:scrape_pottery_sherd"
    Sculk = "minecraft:sculk"
    SculkCatalyst = "minecraft:sculk_catalyst"
    SculkSensor = "minecraft:sculk_sensor"
    SculkShrieker = "minecraft:sculk_shrieker"
    SculkVein = "minecraft:sculk_vein"
    SeaLantern = "minecraft:sea_lantern"
    SeaPickle = "minecraft:sea_pickle"
    Seagrass = "minecraft:seagrass"
    SentryArmorTrimSmithingTemplate = "minecraft:sentry_armor_trim_smithing_template"
    ShaperArmorTrimSmithingTemplate = "minecraft:shaper_armor_trim_smithing_template"
    SheafPotterySherd = "minecraft:sheaf_pottery_sherd"
    Shears = "minecraft:shears"
    SheepSpawnEgg = "minecraft:sheep_spawn_egg"
    ShelterPotterySherd = "minecraft:shelter_pottery_sherd"
    Shield = "minecraft:shield"
    ShortDryGrass = "minecraft:short_dry_grass"
    ShortGrass = "minecraft:short_grass"
    Shroomlight = "minecraft:shroomlight"
    ShulkerShell = "minecraft:shulker_shell"
    ShulkerSpawnEgg = "minecraft:shulker_spawn_egg"
    SilenceArmorTrimSmithingTemplate = "minecraft:silence_armor_trim_smithing_template"
    SilverGlazedTerracotta = "minecraft:silver_glazed_terracotta"
    SilverfishSpawnEgg = "minecraft:silverfish_spawn_egg"
    SkeletonHorseSpawnEgg = "minecraft:skeleton_horse_spawn_egg"
    SkeletonSkull = "minecraft:skeleton_skull"
    SkeletonSpawnEgg = "minecraft:skeleton_spawn_egg"
    SkullBannerPattern = "minecraft:skull_banner_pattern"
    SkullPotterySherd = "minecraft:skull_pottery_sherd"
    Slime = "minecraft:slime"
    SlimeBall = "minecraft:slime_ball"
    SlimeSpawnEgg = "minecraft:slime_spawn_egg"
    SmallAmethystBud = "minecraft:small_amethyst_bud"
    SmallDripleafBlock = "minecraft:small_dripleaf_block"
    SmithingTable = "minecraft:smithing_table"
    Smoker = "minecraft:smoker"
    SmoothBasalt = "minecraft:smooth_basalt"
    SmoothQuartz = "minecraft:smooth_quartz"
    SmoothQuartzSlab = "minecraft:smooth_quartz_slab"
    SmoothQuartzStairs = "minecraft:smooth_quartz_stairs"
    SmoothRedSandstone = "minecraft:smooth_red_sandstone"
    SmoothRedSandstoneSlab = "minecraft:smooth_red_sandstone_slab"
    SmoothRedSandstoneStairs = "minecraft:smooth_red_sandstone_stairs"
    SmoothSandstone = "minecraft:smooth_sandstone"
    SmoothSandstoneSlab = "minecraft:smooth_sandstone_slab"
    SmoothSandstoneStairs = "minecraft:smooth_sandstone_stairs"
    SmoothStone = "minecraft:smooth_stone"
    SmoothStoneSlab = "minecraft:smooth_stone_slab"
    SnifferEgg = "minecraft:sniffer_egg"
    SnifferSpawnEgg = "minecraft:sniffer_spawn_egg"
    SnortPotterySherd = "minecraft:snort_pottery_sherd"
    SnoutArmorTrimSmithingTemplate = "minecraft:snout_armor_trim_smithing_template"
    Snow = "minecraft:snow"
    SnowGolemSpawnEgg = "minecraft:snow_golem_spawn_egg"
    SnowLayer = "minecraft:snow_layer"
    Snowball = "minecraft:snowball"
    SoulCampfire = "minecraft:soul_campfire"
    SoulLantern = "minecraft:soul_lantern"
    SoulSand = "minecraft:soul_sand"
    SoulSoil = "minecraft:soul_soil"
    SoulTorch = "minecraft:soul_torch"
    SpiderEye = "minecraft:spider_eye"
    SpiderSpawnEgg = "minecraft:spider_spawn_egg"
    SpireArmorTrimSmithingTemplate = "minecraft:spire_armor_trim_smithing_template"
    SplashPotion = "minecraft:splash_potion"
    Sponge = "minecraft:sponge"
    SporeBlossom = "minecraft:spore_blossom"
    SpruceBoat = "minecraft:spruce_boat"
    SpruceButton = "minecraft:spruce_button"
    SpruceChestBoat = "minecraft:spruce_chest_boat"
    SpruceDoor = "minecraft:spruce_door"
    SpruceFence = "minecraft:spruce_fence"
    SpruceFenceGate = "minecraft:spruce_fence_gate"
    SpruceHangingSign = "minecraft:spruce_hanging_sign"
    SpruceLeaves = "minecraft:spruce_leaves"
    SpruceLog = "minecraft:spruce_log"
    SprucePlanks = "minecraft:spruce_planks"
    SprucePressurePlate = "minecraft:spruce_pressure_plate"
    SpruceSapling = "minecraft:spruce_sapling"
    SpruceSign = "minecraft:spruce_sign"
    SpruceSlab = "minecraft:spruce_slab"
    SpruceStairs = "minecraft:spruce_stairs"
    SpruceTrapdoor = "minecraft:spruce_trapdoor"
    SpruceWood = "minecraft:spruce_wood"
    Spyglass = "minecraft:spyglass"
    SquidSpawnEgg = "minecraft:squid_spawn_egg"
    Stick = "minecraft:stick"
    StickyPiston = "minecraft:sticky_piston"
    Stone = "minecraft:stone"
    StoneAxe = "minecraft:stone_axe"
    StoneBrickSlab = "minecraft:stone_brick_slab"
    StoneBrickStairs = "minecraft:stone_brick_stairs"
    StoneBrickWall = "minecraft:stone_brick_wall"
    StoneBricks = "minecraft:stone_bricks"
    StoneButton = "minecraft:stone_button"
    StoneHoe = "minecraft:stone_hoe"
    StonePickaxe = "minecraft:stone_pickaxe"
    StonePressurePlate = "minecraft:stone_pressure_plate"
    StoneShovel = "minecraft:stone_shovel"
    StoneStairs = "minecraft:stone_stairs"
    StoneSword = "minecraft:stone_sword"
    StonecutterBlock = "minecraft:stonecutter_block"
    StraySpawnEgg = "minecraft:stray_spawn_egg"
    StriderSpawnEgg = "minecraft:strider_spawn_egg"
    String = "minecraft:string"
    StrippedAcaciaLog = "minecraft:stripped_acacia_log"
    StrippedAcaciaWood = "minecraft:stripped_acacia_wood"
    StrippedBambooBlock = "minecraft:stripped_bamboo_block"
    StrippedBirchLog = "minecraft:stripped_birch_log"
    StrippedBirchWood = "minecraft:stripped_birch_wood"
    StrippedCherryLog = "minecraft:stripped_cherry_log"
    StrippedCherryWood = "minecraft:stripped_cherry_wood"
    StrippedCrimsonHyphae = "minecraft:stripped_crimson_hyphae"
    StrippedCrimsonStem = "minecraft:stripped_crimson_stem"
    StrippedDarkOakLog = "minecraft:stripped_dark_oak_log"
    StrippedDarkOakWood = "minecraft:stripped_dark_oak_wood"
    StrippedJungleLog = "minecraft:stripped_jungle_log"
    StrippedJungleWood = "minecraft:stripped_jungle_wood"
    StrippedMangroveLog = "minecraft:stripped_mangrove_log"
    StrippedMangroveWood = "minecraft:stripped_mangrove_wood"
    StrippedOakLog = "minecraft:stripped_oak_log"
    StrippedOakWood = "minecraft:stripped_oak_wood"
    StrippedPaleOakLog = "minecraft:stripped_pale_oak_log"
    StrippedPaleOakWood = "minecraft:stripped_pale_oak_wood"
    StrippedSpruceLog = "minecraft:stripped_spruce_log"
    StrippedSpruceWood = "minecraft:stripped_spruce_wood"
    StrippedWarpedHyphae = "minecraft:stripped_warped_hyphae"
    StrippedWarpedStem = "minecraft:stripped_warped_stem"
    StructureBlock = "minecraft:structure_block"
    StructureVoid = "minecraft:structure_void"
    Sugar = "minecraft:sugar"
    SugarCane = "minecraft:sugar_cane"
    Sunflower = "minecraft:sunflower"
    SuspiciousGravel = "minecraft:suspicious_gravel"
    SuspiciousSand = "minecraft:suspicious_sand"
    SuspiciousStew = "minecraft:suspicious_stew"
    SweetBerries = "minecraft:sweet_berries"
    TadpoleBucket = "minecraft:tadpole_bucket"
    TadpoleSpawnEgg = "minecraft:tadpole_spawn_egg"
    TallDryGrass = "minecraft:tall_dry_grass"
    TallGrass = "minecraft:tall_grass"
    Target = "minecraft:target"
    TideArmorTrimSmithingTemplate = "minecraft:tide_armor_trim_smithing_template"
    TintedGlass = "minecraft:tinted_glass"
    Tnt = "minecraft:tnt"
    TntMinecart = "minecraft:tnt_minecart"
    Torch = "minecraft:torch"
    Torchflower = "minecraft:torchflower"
    TorchflowerSeeds = "minecraft:torchflower_seeds"
    TotemOfUndying = "minecraft:totem_of_undying"
    TraderLlamaSpawnEgg = "minecraft:trader_llama_spawn_egg"
    Trapdoor = "minecraft:trapdoor"
    TrappedChest = "minecraft:trapped_chest"
    TrialKey = "minecraft:trial_key"
    TrialSpawner = "minecraft:trial_spawner"
    Trident = "minecraft:trident"
    TripwireHook = "minecraft:tripwire_hook"
    TropicalFish = "minecraft:tropical_fish"
    TropicalFishBucket = "minecraft:tropical_fish_bucket"
    TropicalFishSpawnEgg = "minecraft:tropical_fish_spawn_egg"
    TubeCoral = "minecraft:tube_coral"
    TubeCoralBlock = "minecraft:tube_coral_block"
    TubeCoralFan = "minecraft:tube_coral_fan"
    Tuff = "minecraft:tuff"
    TuffBrickSlab = "minecraft:tuff_brick_slab"
    TuffBrickStairs = "minecraft:tuff_brick_stairs"
    TuffBrickWall = "minecraft:tuff_brick_wall"
    TuffBricks = "minecraft:tuff_bricks"
    TuffSlab = "minecraft:tuff_slab"
    TuffStairs = "minecraft:tuff_stairs"
    TuffWall = "minecraft:tuff_wall"
    TurtleEgg = "minecraft:turtle_egg"
    TurtleHelmet = "minecraft:turtle_helmet"
    TurtleScute = "minecraft:turtle_scute"
    TurtleSpawnEgg = "minecraft:turtle_spawn_egg"
    TwistingVines = "minecraft:twisting_vines"
    UndyedShulkerBox = "minecraft:undyed_shulker_box"
    Vault = "minecraft:vault"
    VerdantFroglight = "minecraft:verdant_froglight"
    VexArmorTrimSmithingTemplate = "minecraft:vex_armor_trim_smithing_template"
    VexSpawnEgg = "minecraft:vex_spawn_egg"
    VillagerSpawnEgg = "minecraft:villager_spawn_egg"
    VindicatorSpawnEgg = "minecraft:vindicator_spawn_egg"
    Vine = "minecraft:vine"
    WanderingTraderSpawnEgg = "minecraft:wandering_trader_spawn_egg"
    WardArmorTrimSmithingTemplate = "minecraft:ward_armor_trim_smithing_template"
    WardenSpawnEgg = "minecraft:warden_spawn_egg"
    WarpedButton = "minecraft:warped_button"
    WarpedDoor = "minecraft:warped_door"
    WarpedFence = "minecraft:warped_fence"
    WarpedFenceGate = "minecraft:warped_fence_gate"
    WarpedFungus = "minecraft:warped_fungus"
    WarpedFungusOnAStick = "minecraft:warped_fungus_on_a_stick"
    WarpedHangingSign = "minecraft:warped_hanging_sign"
    WarpedHyphae = "minecraft:warped_hyphae"
    WarpedNylium = "minecraft:warped_nylium"
    WarpedPlanks = "minecraft:warped_planks"
    WarpedPressurePlate = "minecraft:warped_pressure_plate"
    WarpedRoots = "minecraft:warped_roots"
    WarpedSign = "minecraft:warped_sign"
    WarpedSlab = "minecraft:warped_slab"
    WarpedStairs = "minecraft:warped_stairs"
    WarpedStem = "minecraft:warped_stem"
    WarpedTrapdoor = "minecraft:warped_trapdoor"
    WarpedWartBlock = "minecraft:warped_wart_block"
    WaterBucket = "minecraft:water_bucket"
    Waterlily = "minecraft:waterlily"
    WaxedChiseledCopper = "minecraft:waxed_chiseled_copper"
    WaxedCopper = "minecraft:waxed_copper"
    WaxedCopperBulb = "minecraft:waxed_copper_bulb"
    WaxedCopperDoor = "minecraft:waxed_copper_door"
    WaxedCopperGrate = "minecraft:waxed_copper_grate"
    WaxedCopperTrapdoor = "minecraft:waxed_copper_trapdoor"
    WaxedCutCopper = "minecraft:waxed_cut_copper"
    WaxedCutCopperSlab = "minecraft:waxed_cut_copper_slab"
    WaxedCutCopperStairs = "minecraft:waxed_cut_copper_stairs"
    WaxedExposedChiseledCopper = "minecraft:waxed_exposed_chiseled_copper"
    WaxedExposedCopper = "minecraft:waxed_exposed_copper"
    WaxedExposedCopperBulb = "minecraft:waxed_exposed_copper_bulb"
    WaxedExposedCopperDoor = "minecraft:waxed_exposed_copper_door"
    WaxedExposedCopperGrate = "minecraft:waxed_exposed_copper_grate"
    WaxedExposedCopperTrapdoor = "minecraft:waxed_exposed_copper_trapdoor"
    WaxedExposedCutCopper = "minecraft:waxed_exposed_cut_copper"
    WaxedExposedCutCopperSlab = "minecraft:waxed_exposed_cut_copper_slab"
    WaxedExposedCutCopperStairs = "minecraft:waxed_exposed_cut_copper_stairs"
    WaxedOxidizedChiseledCopper = "minecraft:waxed_oxidized_chiseled_copper"
    WaxedOxidizedCopper = "minecraft:waxed_oxidized_copper"
    WaxedOxidizedCopperBulb = "minecraft:waxed_oxidized_copper_bulb"
    WaxedOxidizedCopperDoor = "minecraft:waxed_oxidized_copper_door"
    WaxedOxidizedCopperGrate = "minecraft:waxed_oxidized_copper_grate"
    WaxedOxidizedCopperTrapdoor = "minecraft:waxed_oxidized_copper_trapdoor"
    WaxedOxidizedCutCopper = "minecraft:waxed_oxidized_cut_copper"
    WaxedOxidizedCutCopperSlab = "minecraft:waxed_oxidized_cut_copper_slab"
    WaxedOxidizedCutCopperStairs = "minecraft:waxed_oxidized_cut_copper_stairs"
    WaxedWeatheredChiseledCopper = "minecraft:waxed_weathered_chiseled_copper"
    WaxedWeatheredCopper = "minecraft:waxed_weathered_copper"
    WaxedWeatheredCopperBulb = "minecraft:waxed_weathered_copper_bulb"
    WaxedWeatheredCopperDoor = "minecraft:waxed_weathered_copper_door"
    WaxedWeatheredCopperGrate = "minecraft:waxed_weathered_copper_grate"
    WaxedWeatheredCopperTrapdoor = "minecraft:waxed_weathered_copper_trapdoor"
    WaxedWeatheredCutCopper = "minecraft:waxed_weathered_cut_copper"
    WaxedWeatheredCutCopperSlab = "minecraft:waxed_weathered_cut_copper_slab"
    WaxedWeatheredCutCopperStairs = "minecraft:waxed_weathered_cut_copper_stairs"
    WayfinderArmorTrimSmithingTemplate = "minecraft:wayfinder_armor_trim_smithing_template"
    WeatheredChiseledCopper = "minecraft:weathered_chiseled_copper"
    WeatheredCopper = "minecraft:weathered_copper"
    WeatheredCopperBulb = "minecraft:weathered_copper_bulb"
    WeatheredCopperDoor = "minecraft:weathered_copper_door"
    WeatheredCopperGrate = "minecraft:weathered_copper_grate"
    WeatheredCopperTrapdoor = "minecraft:weathered_copper_trapdoor"
    WeatheredCutCopper = "minecraft:weathered_cut_copper"
    WeatheredCutCopperSlab = "minecraft:weathered_cut_copper_slab"
    WeatheredCutCopperStairs = "minecraft:weathered_cut_copper_stairs"
    Web = "minecraft:web"
    WeepingVines = "minecraft:weeping_vines"
    WetSponge = "minecraft:wet_sponge"
    Wheat = "minecraft:wheat"
    WheatSeeds = "minecraft:wheat_seeds"
    WhiteBundle = "minecraft:white_bundle"
    WhiteCandle = "minecraft:white_candle"
    WhiteCarpet = "minecraft:white_carpet"
    WhiteConcrete = "minecraft:white_concrete"
    WhiteConcretePowder = "minecraft:white_concrete_powder"
    WhiteDye = "minecraft:white_dye"
    WhiteGlazedTerracotta = "minecraft:white_glazed_terracotta"
    WhiteHarness = "minecraft:white_harness"
    WhiteShulkerBox = "minecraft:white_shulker_box"
    WhiteStainedGlass = "minecraft:white_stained_glass"
    WhiteStainedGlassPane = "minecraft:white_stained_glass_pane"
    WhiteTerracotta = "minecraft:white_terracotta"
    WhiteTulip = "minecraft:white_tulip"
    WhiteWool = "minecraft:white_wool"
    WildArmorTrimSmithingTemplate = "minecraft:wild_armor_trim_smithing_template"
    Wildflowers = "minecraft:wildflowers"
    WindCharge = "minecraft:wind_charge"
    WitchSpawnEgg = "minecraft:witch_spawn_egg"
    WitherRose = "minecraft:wither_rose"
    WitherSkeletonSkull = "minecraft:wither_skeleton_skull"
    WitherSkeletonSpawnEgg = "minecraft:wither_skeleton_spawn_egg"
    WitherSpawnEgg = "minecraft:wither_spawn_egg"
    WolfArmor = "minecraft:wolf_armor"
    WolfSpawnEgg = "minecraft:wolf_spawn_egg"
    WoodenAxe = "minecraft:wooden_axe"
    WoodenButton = "minecraft:wooden_button"
    WoodenDoor = "minecraft:wooden_door"
    WoodenHoe = "minecraft:wooden_hoe"
    WoodenPickaxe = "minecraft:wooden_pickaxe"
    WoodenPressurePlate = "minecraft:wooden_pressure_plate"
    WoodenShovel = "minecraft:wooden_shovel"
    WoodenSword = "minecraft:wooden_sword"
    WritableBook = "minecraft:writable_book"
    YellowBundle = "minecraft:yellow_bundle"
    YellowCandle = "minecraft:yellow_candle"
    YellowCarpet = "minecraft:yellow_carpet"
    YellowConcrete = "minecraft:yellow_concrete"
    YellowConcretePowder = "minecraft:yellow_concrete_powder"
    YellowDye = "minecraft:yellow_dye"
    YellowGlazedTerracotta = "minecraft:yellow_glazed_terracotta"
    YellowHarness = "minecraft:yellow_harness"
    YellowShulkerBox = "minecraft:yellow_shulker_box"
    YellowStainedGlass = "minecraft:yellow_stained_glass"
    YellowStainedGlassPane = "minecraft:yellow_stained_glass_pane"
    YellowTerracotta = "minecraft:yellow_terracotta"
    YellowWool = "minecraft:yellow_wool"
    ZoglinSpawnEgg = "minecraft:zoglin_spawn_egg"
    ZombieHead = "minecraft:zombie_head"
    ZombieHorseSpawnEgg = "minecraft:zombie_horse_spawn_egg"
    ZombiePigmanSpawnEgg = "minecraft:zombie_pigman_spawn_egg"
    ZombieSpawnEgg = "minecraft:zombie_spawn_egg"
    ZombieVillagerSpawnEgg = "minecraft:zombie_villager_spawn_egg"
