from anvil.lib.schemas import MinecraftEntityDescriptor

class MinecraftEntityTypes:
    Agent = MinecraftEntityDescriptor("minecraft:agent", True, True)
    Allay = MinecraftEntityDescriptor("minecraft:allay", True, True)
    AreaEffectCloud = MinecraftEntityDescriptor("minecraft:area_effect_cloud", True, True)
    Armadillo = MinecraftEntityDescriptor("minecraft:armadillo", True, True)
    ArmorStand = MinecraftEntityDescriptor("minecraft:armor_stand", True, True)
    Arrow = MinecraftEntityDescriptor("minecraft:arrow", True, True)
    Axolotl = MinecraftEntityDescriptor("minecraft:axolotl", True, True)
    Bat = MinecraftEntityDescriptor("minecraft:bat", True, True)
    Bee = MinecraftEntityDescriptor("minecraft:bee", True, True)
    Blaze = MinecraftEntityDescriptor("minecraft:blaze", True, True)
    Boat = MinecraftEntityDescriptor("minecraft:boat", True, True)
    Bogged = MinecraftEntityDescriptor("minecraft:bogged", True, True)
    Breeze = MinecraftEntityDescriptor("minecraft:breeze", True, True)
    BreezeWindChargeProjectile = MinecraftEntityDescriptor("minecraft:breeze_wind_charge_projectile", True, True)
    Camel = MinecraftEntityDescriptor("minecraft:camel", True, True)
    Cat = MinecraftEntityDescriptor("minecraft:cat", True, True)
    CaveSpider = MinecraftEntityDescriptor("minecraft:cave_spider", True, True)
    ChestBoat = MinecraftEntityDescriptor("minecraft:chest_boat", True, True)
    ChestMinecart = MinecraftEntityDescriptor("minecraft:chest_minecart", True, True)
    Chicken = MinecraftEntityDescriptor("minecraft:chicken", True, True)
    Cod = MinecraftEntityDescriptor("minecraft:cod", True, True)
    CommandBlockMinecart = MinecraftEntityDescriptor("minecraft:command_block_minecart", True, True)
    Cow = MinecraftEntityDescriptor("minecraft:cow", True, True)
    Creaking = MinecraftEntityDescriptor("minecraft:creaking", True, True)
    Creeper = MinecraftEntityDescriptor("minecraft:creeper", True, True)
    Dolphin = MinecraftEntityDescriptor("minecraft:dolphin", True, True)
    Donkey = MinecraftEntityDescriptor("minecraft:donkey", True, True)
    DragonFireball = MinecraftEntityDescriptor("minecraft:dragon_fireball", True, True)
    Drowned = MinecraftEntityDescriptor("minecraft:drowned", True, True)
    Egg = MinecraftEntityDescriptor("minecraft:egg", True, True)
    ElderGuardian = MinecraftEntityDescriptor("minecraft:elder_guardian", True, True)
    EnderCrystal = MinecraftEntityDescriptor("minecraft:ender_crystal", True, True)
    EnderDragon = MinecraftEntityDescriptor("minecraft:ender_dragon", True, True)
    EnderPearl = MinecraftEntityDescriptor("minecraft:ender_pearl", True, True)
    Enderman = MinecraftEntityDescriptor("minecraft:enderman", True, True)
    Endermite = MinecraftEntityDescriptor("minecraft:endermite", True, True)
    EvocationIllager = MinecraftEntityDescriptor("minecraft:evocation_illager", True, True)
    EyeOfEnderSignal = MinecraftEntityDescriptor("minecraft:eye_of_ender_signal", True, True)
    Fireball = MinecraftEntityDescriptor("minecraft:fireball", True, True)
    FireworksRocket = MinecraftEntityDescriptor("minecraft:fireworks_rocket", True, True)
    FishingHook = MinecraftEntityDescriptor("minecraft:fishing_hook", True, True)
    Fox = MinecraftEntityDescriptor("minecraft:fox", True, True)
    Frog = MinecraftEntityDescriptor("minecraft:frog", True, True)
    Ghast = MinecraftEntityDescriptor("minecraft:ghast", True, True)
    GlowSquid = MinecraftEntityDescriptor("minecraft:glow_squid", True, True)
    Goat = MinecraftEntityDescriptor("minecraft:goat", True, True)
    Guardian = MinecraftEntityDescriptor("minecraft:guardian", True, True)
    HappyGhast = MinecraftEntityDescriptor("minecraft:happy_ghast", True, True)
    Hoglin = MinecraftEntityDescriptor("minecraft:hoglin", True, True)
    HopperMinecart = MinecraftEntityDescriptor("minecraft:hopper_minecart", True, True)
    Horse = MinecraftEntityDescriptor("minecraft:horse", True, True)
    Husk = MinecraftEntityDescriptor("minecraft:husk", True, True)
    IronGolem = MinecraftEntityDescriptor("minecraft:iron_golem", True, True)
    LightningBolt = MinecraftEntityDescriptor("minecraft:lightning_bolt", True, True)
    LingeringPotion = MinecraftEntityDescriptor("minecraft:lingering_potion", True, True)
    Llama = MinecraftEntityDescriptor("minecraft:llama", True, True)
    LlamaSpit = MinecraftEntityDescriptor("minecraft:llama_spit", True, True)
    MagmaCube = MinecraftEntityDescriptor("minecraft:magma_cube", True, True)
    Minecart = MinecraftEntityDescriptor("minecraft:minecart", True, True)
    Mooshroom = MinecraftEntityDescriptor("minecraft:mooshroom", True, True)
    Mule = MinecraftEntityDescriptor("minecraft:mule", True, True)
    Npc = MinecraftEntityDescriptor("minecraft:npc", True, True)
    Ocelot = MinecraftEntityDescriptor("minecraft:ocelot", True, True)
    OminousItemSpawner = MinecraftEntityDescriptor("minecraft:ominous_item_spawner", True, True)
    Panda = MinecraftEntityDescriptor("minecraft:panda", True, True)
    Parrot = MinecraftEntityDescriptor("minecraft:parrot", True, True)
    Phantom = MinecraftEntityDescriptor("minecraft:phantom", True, True)
    Pig = MinecraftEntityDescriptor("minecraft:pig", True, True)
    Piglin = MinecraftEntityDescriptor("minecraft:piglin", True, True)
    PiglinBrute = MinecraftEntityDescriptor("minecraft:piglin_brute", True, True)
    Pillager = MinecraftEntityDescriptor("minecraft:pillager", True, True)
    Player = MinecraftEntityDescriptor("minecraft:player", True, True)
    PolarBear = MinecraftEntityDescriptor("minecraft:polar_bear", True, True)
    Pufferfish = MinecraftEntityDescriptor("minecraft:pufferfish", True, True)
    Rabbit = MinecraftEntityDescriptor("minecraft:rabbit", True, True)
    Ravager = MinecraftEntityDescriptor("minecraft:ravager", True, True)
    Salmon = MinecraftEntityDescriptor("minecraft:salmon", True, True)
    Sheep = MinecraftEntityDescriptor("minecraft:sheep", True, True)
    Shulker = MinecraftEntityDescriptor("minecraft:shulker", True, True)
    ShulkerBullet = MinecraftEntityDescriptor("minecraft:shulker_bullet", True, True)
    Silverfish = MinecraftEntityDescriptor("minecraft:silverfish", True, True)
    Skeleton = MinecraftEntityDescriptor("minecraft:skeleton", True, True)
    SkeletonHorse = MinecraftEntityDescriptor("minecraft:skeleton_horse", True, True)
    Slime = MinecraftEntityDescriptor("minecraft:slime", True, True)
    SmallFireball = MinecraftEntityDescriptor("minecraft:small_fireball", True, True)
    Sniffer = MinecraftEntityDescriptor("minecraft:sniffer", True, True)
    SnowGolem = MinecraftEntityDescriptor("minecraft:snow_golem", True, True)
    Snowball = MinecraftEntityDescriptor("minecraft:snowball", True, True)
    Spider = MinecraftEntityDescriptor("minecraft:spider", True, True)
    SplashPotion = MinecraftEntityDescriptor("minecraft:splash_potion", True, True)
    Squid = MinecraftEntityDescriptor("minecraft:squid", True, True)
    Stray = MinecraftEntityDescriptor("minecraft:stray", True, True)
    Strider = MinecraftEntityDescriptor("minecraft:strider", True, True)
    Tadpole = MinecraftEntityDescriptor("minecraft:tadpole", True, True)
    ThrownTrident = MinecraftEntityDescriptor("minecraft:thrown_trident", True, True)
    Tnt = MinecraftEntityDescriptor("minecraft:tnt", True, True)
    TntMinecart = MinecraftEntityDescriptor("minecraft:tnt_minecart", True, True)
    TraderLlama = MinecraftEntityDescriptor("minecraft:trader_llama", True, True)
    TripodCamera = MinecraftEntityDescriptor("minecraft:tripod_camera", True, True)
    Tropicalfish = MinecraftEntityDescriptor("minecraft:tropicalfish", True, True)
    Turtle = MinecraftEntityDescriptor("minecraft:turtle", True, True)
    Vex = MinecraftEntityDescriptor("minecraft:vex", True, True)
    Villager = MinecraftEntityDescriptor("minecraft:villager", True, True)
    VillagerV2 = MinecraftEntityDescriptor("minecraft:villager_v2", True, True)
    Vindicator = MinecraftEntityDescriptor("minecraft:vindicator", True, True)
    WanderingTrader = MinecraftEntityDescriptor("minecraft:wandering_trader", True, True)
    Warden = MinecraftEntityDescriptor("minecraft:warden", True, True)
    WindChargeProjectile = MinecraftEntityDescriptor("minecraft:wind_charge_projectile", True, True)
    Witch = MinecraftEntityDescriptor("minecraft:witch", True, True)
    Wither = MinecraftEntityDescriptor("minecraft:wither", True, True)
    WitherSkeleton = MinecraftEntityDescriptor("minecraft:wither_skeleton", True, True)
    WitherSkull = MinecraftEntityDescriptor("minecraft:wither_skull", True, True)
    WitherSkullDangerous = MinecraftEntityDescriptor("minecraft:wither_skull_dangerous", True, True)
    Wolf = MinecraftEntityDescriptor("minecraft:wolf", True, True)
    XpBottle = MinecraftEntityDescriptor("minecraft:xp_bottle", True, True)
    XpOrb = MinecraftEntityDescriptor("minecraft:xp_orb", True, True)
    Zoglin = MinecraftEntityDescriptor("minecraft:zoglin", True, True)
    Zombie = MinecraftEntityDescriptor("minecraft:zombie", True, True)
    ZombieHorse = MinecraftEntityDescriptor("minecraft:zombie_horse", True, True)
    ZombiePigman = MinecraftEntityDescriptor("minecraft:zombie_pigman", True, True)
    ZombieVillager = MinecraftEntityDescriptor("minecraft:zombie_villager", True, True)
    ZombieVillagerV2 = MinecraftEntityDescriptor("minecraft:zombie_villager_v2", True, True)
